@@ -1,3 +1,6 @@
+use utf8;
+use warnings;
+no warnings 'redefine';
 
 sub newGbookEntry {
     my $message = param('message');
