@@ -5,9 +5,10 @@ use vars qw($sTitle $hrUser @aSelect %hSel @catz @aCats);
 $sTitle  = translate('userprofile');
 $hrUser  = $m_oDatabase->fetch_hashref("select * from  users where user = '$m_sUser'");
 @aSelect = split /\|/, $hrUser->{cats};
+%hSel = ();
 $hSel{$_} = 1 foreach @aSelect;
 @aCats = $m_oDatabase->fetch_AoH("select * from cats where `right` <= ?", $m_nRight);
-
+@catz = ();
 for (my $i = 0 ; $i <= $#aCats ; $i++) {
     push @catz,
       {
@@ -23,7 +24,6 @@ for (my $i = 0 ; $i <= $#aCats ; $i++) {
         -selected         => $hSel{$aCats[$i]->{name}} ? "selected" : '',
       };
 }
-
 show_form(
          -HEADER   => qq(<div class="marginTop">),
          -ACCEPT   => \&on_valid_form,
@@ -131,11 +131,12 @@ sub on_valid_form {
     my $cyrptpass = $md5->hexdigest();
     my $pwChanged = 0;
     my $list;
-
     for (my $i = 0 ; $i <= $#aCats ; $i++)
     {
-        $list .= '|' unless $i == 0;
-        $list .= $aCats[$i]->{name} if (param($aCats[$i]->{name}) eq 'on');
+        if (param($aCats[$i]->{name}) eq 'on'){
+	    $list .= '|' unless $i == 0;
+	    $list .= $aCats[$i]->{name} ;
+        }
     }
     if (   $m_oDatabase->checkPass($m_sUser, $cyrptpass)
         && $newpass eq $retry
@@ -147,12 +148,13 @@ sub on_valid_form {
         my $newpass = $md5->hexdigest();
 
         $m_oDatabase->void(
-            "update `users` set `pass` = '$newpass',`email` = '$email',`name` = '$name',`firstname` ='$firstname',`street` ='$street',`city` = '$city',`postcode` = '$postcode',`phone` ='$phone', cats='$list' where user = '$m_sUser'"
-        );
+            "update `users` set `pass` =  ? ,`email` = ?,`name` = ?,`firstname` = ?,`street` = ?,`city` = ?,`postcode` = ?,`phone` = ?, cats= ? where user = ?"
+        ,$newpass, $email,$name,$firstname,$street,$city,$postcode,$phone,$list,$m_sUser );
         $pass = $retry;
     } else {
         $m_oDatabase->void(
-            "update `users` set `email` = '$email',`name` = '$name',`firstname` ='$firstname',`street` ='$street',`city` = '$city',`postcode` = '$postcode',`phone` ='$phone' , cats='$list' where user = '$m_sUser' "
+            "update `users` set `email` = ?,`name` = ?,`firstname` = ?,`street` = ?,`city` = ?,`postcode` = ?,`phone` =? , cats= ? where user = ? "
+        ,$email,$name,$firstname,$street,$city,$postcode,$phone,$list,$m_sUser
         );
     }
     print '<div class="ShowTables marginTop"><b>'
