@@ -4,7 +4,7 @@ use lib qw(../lib);
 use DBI::Library qw(:all );
 use vars qw($db $m_sUser $host $password $m_hrSettings);
 use MySQL::Admin qw(header init);
-init('/home/groups/l/li/lindnerei/cgi-bin/config/settings.pl');
+init('../config/settings.pl');
 *m_hrSettings = \$MySQL::Admin::m_hrSettings;
 print header;
 my $m_dbh = initDB( { name     => $m_hrSettings->{database}{name},
